@@ -1,12 +1,18 @@
+import hashlib
 import json
 import time
-import hashlib
-import requests
 from datetime import datetime
+from typing import Dict
+
+import requests
 
 from instagrapi.exceptions import (
-    ChallengeRequired, SelectContactPointRecoveryForm, RecaptchaChallengeForm,
-    ChallengeError, ChallengeRedirection, SubmitPhoneNumberForm
+    ChallengeError,
+    ChallengeRedirection,
+    ChallengeRequired,
+    RecaptchaChallengeForm,
+    SelectContactPointRecoveryForm,
+    SubmitPhoneNumberForm,
 )
 
 CHOICE_SMS = 0
@@ -15,9 +21,18 @@ WAIT_SECONDS = 5
 
 
 class ChallengeResolveMixin:
+    """
+    Helpers for resolving login challenge
+    """
 
-    def challenge_resolve(self, last_json):
-        """Start challenge resolve
+    def challenge_resolve(self, last_json: Dict) -> bool:
+        """
+        Start challenge resolve
+
+        Returns
+        -------
+        bool
+            A boolean value
         """
         # START GET REQUEST to challenge_url
         challenge_url = last_json["challenge"]["api_path"]
@@ -42,18 +57,36 @@ class ChallengeResolveMixin:
             return self.challenge_resolve_contact_form(challenge_url)
         return self.challenge_resolve_simple(challenge_url)
 
-    def challenge_resolve_contact_form(self, challenge_url):
+    def challenge_resolve_contact_form(self, challenge_url: str) -> bool:
         """
+        Start challenge resolve
+
         Помогите нам удостовериться, что вы владеете этим аккаунтом
         > CODE
         Верна ли информация вашего профиля?
         Мы заметили подозрительные действия в вашем аккаунте.
         В целях безопасности сообщите, верна ли информация вашего профиля.
         > I AGREE
+
+        Help us make sure you own this account
+        > CODE
+        Is your profile information correct?
+        We have noticed suspicious activity on your account.
+        For security reasons, please let us know if your profile information is correct.
+        > I AGREE
+
+        Parameters
+        ----------
+        challenge_url: str
+            Challenge URL
+
+        Returns
+        -------
+        bool
+            A boolean value
         """
         result = self.last_json
         challenge_url = "https://i.instagram.com%s" % challenge_url
-        print("challenge_resolve_contact_form for %s" % challenge_url)
         enc_password = "#PWD_INSTAGRAM_BROWSER:0:%s:" % datetime.now().strftime("%s")
         instagram_ajax = hashlib.md5(enc_password.encode()).hexdigest()[:12]
         session = requests.Session()
@@ -151,8 +184,6 @@ class ChallengeResolveMixin:
                 if code:
                     break
                 time.sleep(wait_seconds * attempt)
-            print('Enter code "%s" for %s (%d attempts, by %d seconds)' %
-                  (code, self.username, attempt, wait_seconds))
             # SEND CODE
             time.sleep(WAIT_SECONDS)
             result = session.post(challenge_url, {
@@ -196,13 +227,29 @@ class ChallengeResolveMixin:
         assert result.get("status") == "ok", result
         return True
 
-    def handle_challenge_result(self, challenge):
+    def handle_challenge_result(self, challenge: Dict):
+        """
+        Handle challenge result
+
+        Parameters
+        ----------
+        challenge: Dict
+            Dict
+
+        Returns
+        -------
+        bool
+            A boolean value
+        """
         messages = []
         if "challenge" in challenge:
             """
             Иногда в JSON есть вложенность,
             вместо {challege_object}
             приходит {"challenge": {challenge_object}}
+            Sometimes there is nesting in JSON,
+            instead of {challege_object}
+            comes {"challenge": {challenge_object}}
             """
             challenge = challenge["challenge"]
         challenge_type = challenge.get("challengeType")
@@ -289,12 +336,22 @@ class ChallengeResolveMixin:
             raise ChallengeRedirection()
         return challenge
 
-    def challenge_resolve_simple(self, challenge_url):
-        """Old type (through private api) challenge resolver
+    def challenge_resolve_simple(self, challenge_url: str) -> bool:
+        """
+        Old type (through private api) challenge resolver
         Помогите нам удостовериться, что вы владеете этим аккаунтом
+
+        Parameters
+        ----------
+        challenge_url : str
+            Challenge URL
+
+        Returns
+        -------
+        bool
+            A boolean value
         """
         step_name = self.last_json.get("step_name", "")
-        print("challenge_resolve_simple for %s" % challenge_url)
         if step_name == "delta_login_review":
             # IT WAS ME (by GEO)
             self._send_private_request(challenge_url, {"choice": "0"})
